@@ -40,7 +40,8 @@ class IirClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RecognizeProduct", params)
+            headers = request.headers
+            body = self.call("RecognizeProduct", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RecognizeProductResponse()
